==> ocg_login-0.0.13.tar.gz: lib/src/utils/handler.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_facebook_login/flutter_facebook_login.dart';
import 'package:google_sign_in/google_sign_in.dart';
import 'package:ocg_app/ocg_app.dart';

class LoginHandler {
  static Future<AppResponse<OAuthCredential>> signInWithGoogle() async {
    try {
      GoogleSignIn _googleSign = GoogleSignIn();
      await _googleSign.signOut();
      var response = await _googleSign.signIn();
      var authentication = await response.authentication;
      var credential = GoogleAuthProvider.credential(
          accessToken: authentication.accessToken,
          idToken: authentication.idToken);
      return AppResponse.named(data: credential);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "Some error occurred");
    }
  }

  static Future<AppResponse<OAuthCredential>> signInWithFacebook() async {
    try {
      FacebookLogin _facebookLogin = FacebookLogin();
      await _facebookLogin.logOut();
      var authentication = await _facebookLogin.logIn([]);
      switch (authentication.status) {
        case FacebookLoginStatus.cancelledByUser:
          return AppResponse.named(error: "Cancelled by user");
          break;
        case FacebookLoginStatus.loggedIn:
          FacebookAuthCredential credential = FacebookAuthProvider.credential(
            authentication.accessToken.token,
          );
          return AppResponse.named(data: credential);
          break;
        default:
          return AppResponse.named(error: "Some error occurred");
      }
    } catch (e) {
      return AppResponse.named(error: "$e");
    }
  }
}

==> ocg_login-0.0.14.tar.gz: lib/src/utils/handler.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_facebook_login/flutter_facebook_login.dart';
import 'package:google_sign_in/google_sign_in.dart';
import 'package:ocg_app/ocg_app.dart';

class LoginHandler {
  static Future<AppResponse<AuthCredential>> signInWithGoogle() async {
    try {
      GoogleSignIn _googleSign = GoogleSignIn();
      await _googleSign.signOut();
      var response = await _googleSign.signIn();
      var authentication = await response.authentication;
      var credential = GoogleAuthProvider.getCredential(
          accessToken: authentication.accessToken,
          idToken: authentication.idToken);
      return AppResponse.named(data: credential);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "Some error occurred");
    }
  }

  static Future<AppResponse<AuthCredential>> signInWithFacebook() async {
    try {
      FacebookLogin _facebookLogin = FacebookLogin();
      await _facebookLogin.logOut();
      var authentication = await _facebookLogin.logIn([]);
      switch (authentication.status) {
        case FacebookLoginStatus.cancelledByUser:
          return AppResponse.named(error: "Cancelled by user");
          break;
        case FacebookLoginStatus.loggedIn:
          AuthCredential credential = FacebookAuthProvider.getCredential(
            accessToken: authentication.accessToken.token,
          );
          return AppResponse.named(data: credential);
          break;
        default:
          return AppResponse.named(error: "Some error occurred");
      }
    } catch (e) {
      return AppResponse.named(error: "$e");
    }
  }
}
